Rename

  * _Configuration_Interrupt_stack_area_begin in _ISR_Stack_area_begin,
  * _Configuration_Interrupt_stack_area_end in _ISR_Stack_area_end, and
  * _Configuration_Interrupt_stack_size in _ISR_Stack_size.

Move definitions to <rtems/score/isr.h>.  The new names are considerable
shorter and in the right namespace.
---
 bsps/arm/csb336/start/start.S            |  2 +-
 bsps/arm/csb337/start/start.S            |  2 +-
 bsps/arm/edb7312/start/start.S           |  2 +-
 bsps/arm/gumstix/start/start.S           |  2 +-
 bsps/arm/rtl22xx/start/start.S           |  2 +-
 bsps/arm/shared/start/start.S            |  8 ++++----
 bsps/arm/smdk2410/start/start.S          |  2 +-
 bsps/lm32/shared/start/start.S           |  4 ++--
 bsps/m32c/m32cbsp/start/start.S          |  2 +-
 bsps/m68k/gen68340/start/start.S         |  2 +-
 bsps/m68k/gen68360/start/start.S         |  2 +-
 bsps/m68k/genmcf548x/start/start.S       |  4 ++--
 bsps/m68k/mcf52235/start/start.S         |  6 +++---
 bsps/m68k/mcf5225x/start/start.S         |  6 +++---
 bsps/m68k/mcf5329/start/start.S          |  4 ++--
 bsps/m68k/mrm332/start/start.S           |  2 +-
 bsps/m68k/shared/start/start.S           |  2 +-
 bsps/mips/csb350/start/start.S           |  2 +-
 bsps/mips/jmr3904/start/start.S          |  2 +-
 bsps/mips/malta/start/start.S            |  2 +-
 bsps/powerpc/gen83xx/start/start.S       |  2 +-
 bsps/powerpc/haleakala/start/dlentry.S   |  4 ++--
 bsps/powerpc/include/bsp/vectors.h       |  2 +-
 bsps/powerpc/mpc55xxevb/start/bspstart.c |  2 +-
 bsps/powerpc/mpc55xxevb/start/start.S    |  2 +-
 bsps/powerpc/psim/start/bspstart.c       |  2 +-
 bsps/powerpc/psim/start/start.S          |  2 +-
 bsps/powerpc/qemuppc/start/start.S       |  4 ++--
 bsps/powerpc/qoriq/start/bspstart.c      |  2 +-
 bsps/powerpc/qoriq/start/start.S         |  4 ++--
 bsps/powerpc/ss555/start/bspstart.c      |  2 +-
 bsps/powerpc/ss555/start/start.S         |  2 +-
 bsps/powerpc/t32mppc/start/bspstart.c    |  2 +-
 bsps/powerpc/t32mppc/start/start.S       |  2 +-
 bsps/powerpc/tqm8xx/start/start.S        |  2 +-
 bsps/powerpc/virtex/start/bspstart.c     |  2 +-
 bsps/powerpc/virtex4/start/start.S       |  4 ++--
 bsps/powerpc/virtex5/start/start.S       |  4 ++--
 bsps/riscv/riscv/start/start.S           |  6 +++---
 bsps/sh/gensh1/start/start.S             |  2 +-
 bsps/sh/gensh2/start/start.S             |  2 +-
 bsps/sh/gensh2/start/start.ram           |  2 +-
 bsps/sh/gensh2/start/start.rom           |  2 +-
 bsps/sh/gensh4/start/start.S             |  2 +-
 bsps/sh/shsim/start/start.S              |  2 +-
 bsps/sparc/shared/start/start.S          |  4 ++--
 bsps/v850/gdbv850sim/start/start.S       |  6 +++---
 cpukit/include/rtems/confdefs.h          |  6 +++---
 cpukit/include/rtems/config.h            | 29 ++---------------------------
 cpukit/include/rtems/score/isr.h         | 26 ++++++++++++++++++++++++++
 cpukit/libmisc/stackchk/check.c          |  2 +-
 cpukit/score/cpu/m68k/cpu.c              |  2 +-
 cpukit/score/src/isr.c                   |  2 +-
 53 files changed, 101 insertions(+), 100 deletions(-)

diff --git a/bsps/arm/csb336/start/start.S b/bsps/arm/csb336/start/start.S
index 2ef4cb71fa..acb75debad 100644
--- a/bsps/arm/csb336/start/start.S
+++ b/bsps/arm/csb336/start/start.S
@@ -27,7 +27,7 @@ _start:
          */
 
         /* Set end of interrupt stack area */
-        ldr     r7, =_Configuration_Interrupt_stack_area_end
+        ldr     r7, =_ISR_Stack_area_end
 
         /* Enter FIQ mode and set up the FIQ stack pointer */
         mov     r0, #(ARM_PSR_M_FIQ | ARM_PSR_I | ARM_PSR_F)
diff --git a/bsps/arm/csb337/start/start.S b/bsps/arm/csb337/start/start.S
index a755864d0d..d2487278d8 100644
--- a/bsps/arm/csb337/start/start.S
+++ b/bsps/arm/csb337/start/start.S
@@ -20,7 +20,7 @@ _start:
          */
 
         /* Set end of interrupt stack area */
-        ldr     r7, =_Configuration_Interrupt_stack_area_end
+        ldr     r7, =_ISR_Stack_area_end
 
         /* Enter FIQ mode and set up the FIQ stack pointer */
         mov     r0, #(ARM_PSR_M_FIQ | ARM_PSR_I | ARM_PSR_F)
diff --git a/bsps/arm/edb7312/start/start.S b/bsps/arm/edb7312/start/start.S
index 5806d41ce4..bc70f97293 100644
--- a/bsps/arm/edb7312/start/start.S
+++ b/bsps/arm/edb7312/start/start.S
@@ -60,7 +60,7 @@ handler_addr_fiq:
        .globl  _start
 _start:
         /* Set end of interrupt stack area */
-        ldr     r7, =_Configuration_Interrupt_stack_area_end
+        ldr     r7, =_ISR_Stack_area_end
 
         /* Enter FIQ mode and set up the FIQ stack pointer */
         mov     r0, #(ARM_PSR_M_FIQ | ARM_PSR_I | ARM_PSR_F)
diff --git a/bsps/arm/gumstix/start/start.S b/bsps/arm/gumstix/start/start.S
index 7c71bdacf1..55eb1106a8 100644
--- a/bsps/arm/gumstix/start/start.S
+++ b/bsps/arm/gumstix/start/start.S
@@ -19,7 +19,7 @@ _start:
          */
 
         /* Set end of interrupt stack area */
-        ldr     r7, =_Configuration_Interrupt_stack_area_end
+        ldr     r7, =_ISR_Stack_area_end
 
         /* Enter FIQ mode and set up the FIQ stack pointer */
         mov     r0, #(ARM_PSR_M_FIQ | ARM_PSR_I | ARM_PSR_F)
diff --git a/bsps/arm/rtl22xx/start/start.S b/bsps/arm/rtl22xx/start/start.S
index 0fc265493d..6254d34dd3 100644
--- a/bsps/arm/rtl22xx/start/start.S
+++ b/bsps/arm/rtl22xx/start/start.S
@@ -21,7 +21,7 @@ _start:
          */
 
         /* Set end of interrupt stack area */
-        ldr     r7, =_Configuration_Interrupt_stack_area_end
+        ldr     r7, =_ISR_Stack_area_end
 
         /* Enter FIQ mode and set up the FIQ stack pointer */
         mov     r0, #(ARM_PSR_M_FIQ | ARM_PSR_I | ARM_PSR_F)
diff --git a/bsps/arm/shared/start/start.S b/bsps/arm/shared/start/start.S
index 148625ff97..e4df46f656 100644
--- a/bsps/arm/shared/start/start.S
+++ b/bsps/arm/shared/start/start.S
@@ -181,12 +181,12 @@ _start:
 #endif
 
        /* Calculate interrupt stack area end for current processor */
-       ldr     r1, =_Configuration_Interrupt_stack_size
+       ldr     r1, =_ISR_Stack_size
 #ifdef RTEMS_SMP
        add     r7, #1
        mul     r1, r1, r7
 #endif
-       ldr     r2, =_Configuration_Interrupt_stack_area_begin
+       ldr     r2, =_ISR_Stack_area_begin
        add     r7, r1, r2
 
        /* Save original CPSR value */
@@ -354,7 +354,7 @@ twiddle:
 
 bsp_start_vector_table_begin:
 
-       .word   _Configuration_Interrupt_stack_area_end
+       .word   _ISR_Stack_area_end
        .word   _start /* Reset */
        .word   _ARMV7M_Exception_default /* NMI */
        .word   _ARMV7M_Exception_default /* Hard Fault */
@@ -404,7 +404,7 @@ _start:
 
 #endif /* ARM_MULTILIB_VFP */
 
-       ldr     sp, =_Configuration_Interrupt_stack_area_end
+       ldr     sp, =_ISR_Stack_area_end
        ldr     lr, =bsp_start_hook_0_done + 1
        b       bsp_start_hook_0
 
diff --git a/bsps/arm/smdk2410/start/start.S b/bsps/arm/smdk2410/start/start.S
index b8d1ddefa0..5e4d4655fe 100644
--- a/bsps/arm/smdk2410/start/start.S
+++ b/bsps/arm/smdk2410/start/start.S
@@ -56,7 +56,7 @@ _start2:
          */
 
         /* Set end of interrupt stack area */
-        ldr     r7, =_Configuration_Interrupt_stack_area_end
+        ldr     r7, =_ISR_Stack_area_end
 
         /* Enter FIQ mode and set up the FIQ stack pointer */
         mov     r0, #(ARM_PSR_M_FIQ | ARM_PSR_I | ARM_PSR_F)
diff --git a/bsps/lm32/shared/start/start.S b/bsps/lm32/shared/start/start.S
index 3f4a6c672b..70e4d68859 100644
--- a/bsps/lm32/shared/start/start.S
+++ b/bsps/lm32/shared/start/start.S
@@ -126,8 +126,8 @@ crt0:
        nop
        nop
        /* Initialize stack pointer */
-       mvhi    sp, hi(_Configuration_Interrupt_stack_area_end-4)
-       ori     sp, sp, lo(_Configuration_Interrupt_stack_area_end-4)
+       mvhi    sp, hi(_ISR_Stack_area_end-4)
+       ori     sp, sp, lo(_ISR_Stack_area_end-4)
        /* Initialize global pointer */
        mvhi    gp, hi(_edata)
        ori     gp, gp, lo(_edata)
diff --git a/bsps/m32c/m32cbsp/start/start.S b/bsps/m32c/m32cbsp/start/start.S
index 029cc09a58..f5548784e1 100644
--- a/bsps/m32c/m32cbsp/start/start.S
+++ b/bsps/m32c/m32cbsp/start/start.S
@@ -48,7 +48,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 _start:
 .LFB2:
        fset    U       /* User stack */
-       ldc     #__Configuration_Interrupt_stack_area_end,sp
+       ldc     #__ISR_Stack_area_end,sp
 
 #ifdef A16
        mov.b   #%hi8(__romdatastart),r1h
diff --git a/bsps/m68k/gen68340/start/start.S b/bsps/m68k/gen68340/start/start.S
index 85b9aa86fa..1e00804b87 100644
--- a/bsps/m68k/gen68340/start/start.S
+++ b/bsps/m68k/gen68340/start/start.S
@@ -850,7 +850,7 @@ ZEROLOOPTEST:
        cmpl    a1,a0                                           | Done?
        bcs.s   ZEROLOOP                                        | No, skip
 
-       movel   #_Configuration_Interrupt_stack_area_end,a7             | set 
master stack pointer
+       movel   #_ISR_Stack_area_end,a7         | set master stack pointer
        movel   d0,a7@-                                         | command line
        jsr     SYM(boot_card)                                  | Call C main
 
diff --git a/bsps/m68k/gen68360/start/start.S b/bsps/m68k/gen68360/start/start.S
index 7549f08af8..e1f8122524 100644
--- a/bsps/m68k/gen68360/start/start.S
+++ b/bsps/m68k/gen68360/start/start.S
@@ -390,7 +390,7 @@ ZEROLOOPTEST:
        cmpl    a1,a0                   | Done?
        bcs.s   ZEROLOOP                | No, skip
 
-       movel   #_Configuration_Interrupt_stack_area_end,a7 | set master stack 
pointer
+       movel   #_ISR_Stack_area_end,a7 | set master stack pointer
        movel   d0,a7@-                 | command line
        jsr     boot_card               | Call C main
 
diff --git a/bsps/m68k/genmcf548x/start/start.S 
b/bsps/m68k/genmcf548x/start/start.S
index 1bc09a0118..8495897005 100644
--- a/bsps/m68k/genmcf548x/start/start.S
+++ b/bsps/m68k/genmcf548x/start/start.S
@@ -75,7 +75,7 @@
 .section ".vectors","ax"            /* begin of vectors section */
 PUBLIC (InterruptVectorTable)
 SYM(InterruptVectorTable):
-INITSP:                .long   _Configuration_Interrupt_stack_area_end /* 
Initial SP             */
+INITSP:                .long   _ISR_Stack_area_end /* Initial SP               
  */
 INITPC:                .long   start                   /* Initial PC           
  */
 vector002:     .long   asm_default_interrupt   /* Access Error           */
 vector003:     .long   asm_default_interrupt   /* Address Error          */
@@ -411,7 +411,7 @@ SYM(start_init):
 
     jsr            mcf548x_init                /* Initialize mcf548x 
peripherals */
 
-    move.l  #_Configuration_Interrupt_stack_area_end,sp /* relocate sp */
+    move.l  #_ISR_Stack_area_end,sp /* relocate sp */
 
     clrl    d0                         /* clear d0 */
     movel   d0,a7@-                     /* command line == 0 */
diff --git a/bsps/m68k/mcf52235/start/start.S b/bsps/m68k/mcf52235/start/start.S
index ecb2c5c980..c71f4fed8a 100644
--- a/bsps/m68k/mcf52235/start/start.S
+++ b/bsps/m68k/mcf52235/start/start.S
@@ -21,7 +21,7 @@ BEGIN_CODE
     PUBLIC (_INTERRUPT_VECTOR)
 SYM(_INTERRUPT_VECTOR):
 
-    .long   _Configuration_Interrupt_stack_area_end /* 00 Initial 'SSP' */
+    .long   _ISR_Stack_area_end /* 00 Initial 'SSP' */
     .long   SYM(start) /* 01 Initial PC */
     .long   SYM(_uhoh) /* 02 Access Error */
     .long   SYM(_uhoh) /* 03 Address Error */
@@ -355,7 +355,7 @@ SYM(start):
     movec   d0, %rambar
 
     /* Locate Stack Pointer */
-    move.l  #_Configuration_Interrupt_stack_area_end, sp
+    move.l  #_ISR_Stack_area_end, sp
 
     /* Initialize FLASHBAR */
     move.l  #_FlashBase, d0
@@ -367,7 +367,7 @@ SYM(start):
 _continue_startup:
 
     /* Locate Stack Pointer */
-    move.l  #_Configuration_Interrupt_stack_area_end, sp
+    move.l  #_ISR_Stack_area_end, sp
 
     /* Save off intial D0 and D1 to RAM */
     move.l  d6, SYM(_d0_reset)
diff --git a/bsps/m68k/mcf5225x/start/start.S b/bsps/m68k/mcf5225x/start/start.S
index 19d9038431..4513f663c0 100644
--- a/bsps/m68k/mcf5225x/start/start.S
+++ b/bsps/m68k/mcf5225x/start/start.S
@@ -21,7 +21,7 @@ BEGIN_CODE
     PUBLIC (_INTERRUPT_VECTOR)
 SYM(_INTERRUPT_VECTOR):
 
-    .long   _Configuration_Interrupt_stack_area_end /* 00 Initial 'SSP' */
+    .long   _ISR_Stack_area_end /* 00 Initial 'SSP' */
     .long   SYM(start) /* 01 Initial PC */
     .long   SYM(_uhoh) /* 02 Access Error */
     .long   SYM(_uhoh) /* 03 Address Error */
@@ -359,7 +359,7 @@ SYM(start):
     movec   d7, %rambar
 
     /* Locate Stack Pointer */ 
-    move.l  #_Configuration_Interrupt_stack_area_end, sp
+    move.l  #_ISR_Stack_area_end, sp
 
     /* Initialize FLASHBAR */
     move.l  #_FlashBase, d7
@@ -371,7 +371,7 @@ SYM(start):
 _continue_startup:
 
     /* Locate Stack Pointer */ 
-//    move.l  #_Configuration_Interrupt_stack_area_end, sp             //is 
done automatically by the CPU
+//    move.l  #_ISR_Stack_area_end, sp         //is done automatically by the 
CPU
 
     /*
      * Remainder of the startup code is handled by C code
diff --git a/bsps/m68k/mcf5329/start/start.S b/bsps/m68k/mcf5329/start/start.S
index 659c617272..7a61ffc998 100644
--- a/bsps/m68k/mcf5329/start/start.S
+++ b/bsps/m68k/mcf5329/start/start.S
@@ -21,7 +21,7 @@ BEGIN_CODE
     PUBLIC (_INTERRUPT_VECTOR)
 SYM(_INTERRUPT_VECTOR):
 
-    .long   _Configuration_Interrupt_stack_area_end /* 00 Initial 'SSP' */
+    .long   _ISR_Stack_area_end /* 00 Initial 'SSP' */
     .long   SYM(start) /* 01 Initial PC */
     .long   SYM(_uhoh) /* 02 Access Error */
     .long   SYM(_uhoh) /* 03 Address Error */
@@ -344,7 +344,7 @@ SYM(start):
     move.l  d7, SYM(_d1_reset)
 
     /* Locate Stack Pointer */
-    move.l  #_Configuration_Interrupt_stack_area_end,sp
+    move.l  #_ISR_Stack_area_end,sp
 
     /*
      * Remainder of the startup code is handled by C code
diff --git a/bsps/m68k/mrm332/start/start.S b/bsps/m68k/mrm332/start/start.S
index 300b74fc78..0cf691cd28 100644
--- a/bsps/m68k/mrm332/start/start.S
+++ b/bsps/m68k/mrm332/start/start.S
@@ -38,7 +38,7 @@ BEGIN_CODE
        movecl  d0,vbr
 
        /* Set stack pointer */
-       movel   #_Configuration_Interrupt_stack_area_end,d0
+       movel   #_ISR_Stack_area_end,d0
        movel   d0,sp
        movel   d0,a6
 
diff --git a/bsps/m68k/shared/start/start.S b/bsps/m68k/shared/start/start.S
index 9c40cbc3da..3ee7917814 100644
--- a/bsps/m68k/shared/start/start.S
+++ b/bsps/m68k/shared/start/start.S
@@ -74,7 +74,7 @@ loop:   movel   #0,a1@+                 | to zero out 
uninitialized
         cmpal   a0,a1
         jlt     loop                    | loop until _end reached
 
-        movel   # SYM (_Configuration_Interrupt_stack_area_end),d0 | d0 = stop 
of stack
+        movel   # SYM (_ISR_Stack_area_end),d0 | d0 = stop of stack
         movw    #0x3700,sr              | SUPV MODE,INTERRUPTS OFF!!!
         movel   d0,a7                   | set master stack pointer
         movel   d0,a6                   | set base pointer
diff --git a/bsps/mips/csb350/start/start.S b/bsps/mips/csb350/start/start.S
index dc92f1a430..b21dc41917 100644
--- a/bsps/mips/csb350/start/start.S
+++ b/bsps/mips/csb350/start/start.S
@@ -67,7 +67,7 @@ zerobss:
        bltu    v0,v1,3b
        addiu   v0,v0,4                 /* executed in delay slot */
 
-       la      t0, _Configuration_Interrupt_stack_area_end /* initialize stack 
so we */
+       la      t0, _ISR_Stack_area_end /* initialize stack so we */
        /* We must subtract 24 bytes for the 3 8 byte arguments to main, in
           case main wants to write them back to the stack.  The caller is
           supposed to allocate stack space for parameters in registers in
diff --git a/bsps/mips/jmr3904/start/start.S b/bsps/mips/jmr3904/start/start.S
index 9e1fa4182b..9106216c21 100644
--- a/bsps/mips/jmr3904/start/start.S
+++ b/bsps/mips/jmr3904/start/start.S
@@ -139,7 +139,7 @@ zerobss:
        bltu    v0,v1,3b
        addiu   v0,v0,4                         # executed in delay slot
 
-       la      t0, _Configuration_Interrupt_stack_area_end # initialize stack 
so we
+       la      t0, _ISR_Stack_area_end # initialize stack so we
        /* We must subtract 24 bytes for the 3 8 byte arguments to main, in
           case main wants to write them back to the stack.  The caller is
           supposed to allocate stack space for parameters in registers in
diff --git a/bsps/mips/malta/start/start.S b/bsps/mips/malta/start/start.S
index d437575cca..2fdc29f190 100644
--- a/bsps/mips/malta/start/start.S
+++ b/bsps/mips/malta/start/start.S
@@ -166,7 +166,7 @@ zerobss:
        bltu    v0,v1,3b
        addiu   v0,v0,4                         # executed in delay slot
 
-       la      t0, _Configuration_Interrupt_stack_area_end # initialize stack 
so we
+       la      t0, _ISR_Stack_area_end # initialize stack so we
        /* We must subtract 24 bytes for the 3 8 byte arguments to main, in
           case main wants to write them back to the stack.  The caller is
           supposed to allocate stack space for parameters in registers in
diff --git a/bsps/powerpc/gen83xx/start/start.S 
b/bsps/powerpc/gen83xx/start/start.S
index 9272702d6b..532210e4b9 100644
--- a/bsps/powerpc/gen83xx/start/start.S
+++ b/bsps/powerpc/gen83xx/start/start.S
@@ -417,7 +417,7 @@ start_code_in_ram:
        li      r3, 0
 
        /* Set start stack pointer */
-       LA      r1, _Configuration_Interrupt_stack_area_end
+       LA      r1, _ISR_Stack_area_end
        stwu    r3, -4(r1)
        stwu    r3, -4(r1)
 
diff --git a/bsps/powerpc/include/bsp/vectors.h 
b/bsps/powerpc/include/bsp/vectors.h
index 88c60bc8cd..eccf4f3738 100644
--- a/bsps/powerpc/include/bsp/vectors.h
+++ b/bsps/powerpc/include/bsp/vectors.h
@@ -343,7 +343,7 @@ void ppc_exc_initialize_with_vector_base(
 static inline void ppc_exc_initialize(void)
 {
   ppc_exc_initialize_with_vector_base(
-    (uintptr_t) _Configuration_Interrupt_stack_area_begin,
+    (uintptr_t) _ISR_Stack_area_begin,
     NULL
   );
 }
diff --git a/bsps/powerpc/mpc55xxevb/start/bspstart.c 
b/bsps/powerpc/mpc55xxevb/start/bspstart.c
index 5d4c1caf43..0da53cab2b 100644
--- a/bsps/powerpc/mpc55xxevb/start/bspstart.c
+++ b/bsps/powerpc/mpc55xxevb/start/bspstart.c
@@ -89,7 +89,7 @@ void bsp_start(void)
        bsp_clicks_per_usec = bsp_clock_speed / 1000000;
 
        ppc_exc_initialize_with_vector_base(
-               (uintptr_t) _Configuration_Interrupt_stack_area_begin,
+               (uintptr_t) _ISR_Stack_area_begin,
                mpc55xx_exc_vector_base
        );
        bsp_interrupt_initialize();
diff --git a/bsps/powerpc/mpc55xxevb/start/start.S 
b/bsps/powerpc/mpc55xxevb/start/start.S
index 81893b6276..ff38d619b2 100644
--- a/bsps/powerpc/mpc55xxevb/start/start.S
+++ b/bsps/powerpc/mpc55xxevb/start/start.S
@@ -228,7 +228,7 @@ zero_intermediate_stack_loop:
        bl      mpc55xx_start_early
 
        /* Initialize start stack */
-       LA      r1, _Configuration_Interrupt_stack_area_end
+       LA      r1, _ISR_Stack_area_end
        subi    r1, r1, 16
        li      r0, 0
        stw     r0, 0(r1)
diff --git a/bsps/powerpc/psim/start/bspstart.c 
b/bsps/powerpc/psim/start/bspstart.c
index a7a73b7e7b..4fcc3ac01c 100644
--- a/bsps/powerpc/psim/start/bspstart.c
+++ b/bsps/powerpc/psim/start/bspstart.c
@@ -88,7 +88,7 @@ void bsp_start( void )
   BSP_time_base_divisor    = 1;
 
   ppc_exc_initialize_with_vector_base(
-    (uintptr_t) _Configuration_Interrupt_stack_area_begin,
+    (uintptr_t) _ISR_Stack_area_begin,
     (void *) 0xfff00000
   );
 
diff --git a/bsps/powerpc/psim/start/start.S b/bsps/powerpc/psim/start/start.S
index 03cbdedc5b..645a0222c9 100644
--- a/bsps/powerpc/psim/start/start.S
+++ b/bsps/powerpc/psim/start/start.S
@@ -47,7 +47,7 @@ FUNC_NAME(__atexit):                  /* tell C's eabi-ctor's 
we have an atexit function */
        .long   bsp_section_bss_end
 
 .Lstack = .-.LCTOC1                    /* stack address if set by user */
-       .long   _Configuration_Interrupt_stack_area_end
+       .long   _ISR_Stack_area_end
 
        .text
 .Lptr:
diff --git a/bsps/powerpc/qemuppc/start/start.S 
b/bsps/powerpc/qemuppc/start/start.S
index 66cedca9a2..d94d623410 100644
--- a/bsps/powerpc/qemuppc/start/start.S
+++ b/bsps/powerpc/qemuppc/start/start.S
@@ -6,8 +6,8 @@
        .section .bsp_start_text,"awx",@progbits
 
 _start:
-       lis   %r1,_Configuration_Interrupt_stack_area_end@h
-       ori   %r1,%r1,_Configuration_Interrupt_stack_area_end@l
+       lis   %r1,_ISR_Stack_area_end@h
+       ori   %r1,%r1,_ISR_Stack_area_end@l
        /* Make sure stack is properly aligned */
        li    %r3, CPU_STACK_ALIGNMENT - 1
        andc  %r1, %r1, %r3
diff --git a/bsps/powerpc/qoriq/start/bspstart.c 
b/bsps/powerpc/qoriq/start/bspstart.c
index c0b1034736..56935bbb27 100644
--- a/bsps/powerpc/qoriq/start/bspstart.c
+++ b/bsps/powerpc/qoriq/start/bspstart.c
@@ -169,7 +169,7 @@ void bsp_start(void)
   initialize_frequency_parameters();
 
   qoriq_initialize_exceptions(
-    (uintptr_t) _Configuration_Interrupt_stack_area_begin
+    (uintptr_t) _ISR_Stack_area_begin
   );
   bsp_interrupt_initialize();
 
diff --git a/bsps/powerpc/qoriq/start/start.S b/bsps/powerpc/qoriq/start/start.S
index 57342971b6..87db3cfff2 100644
--- a/bsps/powerpc/qoriq/start/start.S
+++ b/bsps/powerpc/qoriq/start/start.S
@@ -56,8 +56,8 @@ _start:
        bl      .Linitearly
 
        /* Get start stack */
-       LA      START_STACK, _Configuration_Interrupt_stack_area_begin
-       LA      r3, _Configuration_Interrupt_stack_size
+       LA      START_STACK, _ISR_Stack_area_begin
+       LA      r3, _ISR_Stack_size
        add     START_STACK, START_STACK, r3
 
        bl      .Linitmore
diff --git a/bsps/powerpc/ss555/start/bspstart.c 
b/bsps/powerpc/ss555/start/bspstart.c
index 5943e2bbd6..cc76c920af 100644
--- a/bsps/powerpc/ss555/start/bspstart.c
+++ b/bsps/powerpc/ss555/start/bspstart.c
@@ -78,7 +78,7 @@ void bsp_start(void)
   /*
    * Initialize some SPRG registers related to irq handling
    */
-  intrStack = (char *)_Configuration_Interrupt_stack_area_end -
+  intrStack = (char *)_ISR_Stack_area_end -
      PPC_MINIMUM_STACK_FRAME_SIZE;
   _write_SPRG1((unsigned int)intrStack);
 
diff --git a/bsps/powerpc/ss555/start/start.S b/bsps/powerpc/ss555/start/start.S
index f17c918b3e..443a40f0ad 100644
--- a/bsps/powerpc/ss555/start/start.S
+++ b/bsps/powerpc/ss555/start/start.S
@@ -220,7 +220,7 @@ base_addr:
  * Parameters from linker
  */
 stack_top:
-       .long   _Configuration_Interrupt_stack_area_end
+       .long   _ISR_Stack_area_end
 
 toc_pointer:
         .long   __GOT_START__
diff --git a/bsps/powerpc/t32mppc/start/bspstart.c 
b/bsps/powerpc/t32mppc/start/bspstart.c
index f7d68340ea..c3d03e789b 100644
--- a/bsps/powerpc/t32mppc/start/bspstart.c
+++ b/bsps/powerpc/t32mppc/start/bspstart.c
@@ -49,7 +49,7 @@ static void t32mppc_initialize_exceptions(void)
   uintptr_t addr;
 
   ppc_exc_initialize_interrupt_stack(
-    (uintptr_t) _Configuration_Interrupt_stack_area_begin
+    (uintptr_t) _ISR_Stack_area_begin
   );
 
   addr = (uintptr_t) bsp_exc_vector_base;
diff --git a/bsps/powerpc/t32mppc/start/start.S 
b/bsps/powerpc/t32mppc/start/start.S
index e4066adb6f..ac7d6f5de7 100644
--- a/bsps/powerpc/t32mppc/start/start.S
+++ b/bsps/powerpc/t32mppc/start/start.S
@@ -34,7 +34,7 @@ _start:
        mtspr   HID0, r0
 
        /* Initialize start stack */
-       LA      r1, _Configuration_Interrupt_stack_area_end
+       LA      r1, _ISR_Stack_area_end
        subi    r1, r1, 16
        li      r0, 0
        stw     r0, 0(r1)
diff --git a/bsps/powerpc/tqm8xx/start/start.S 
b/bsps/powerpc/tqm8xx/start/start.S
index 62e8c5ba86..f134e336da 100644
--- a/bsps/powerpc/tqm8xx/start/start.S
+++ b/bsps/powerpc/tqm8xx/start/start.S
@@ -120,7 +120,7 @@ start_code_in_ram:
         */
 
        /* Set stack pointer (common for RAM/ROM startup) */
-       LA      r1, _Configuration_Interrupt_stack_area_end
+       LA      r1, _ISR_Stack_area_end
         addi    r1, r1, -0x10
 
        /* Create NULL */
diff --git a/bsps/powerpc/virtex/start/bspstart.c 
b/bsps/powerpc/virtex/start/bspstart.c
index 64dbb60898..a4054f1b36 100644
--- a/bsps/powerpc/virtex/start/bspstart.c
+++ b/bsps/powerpc/virtex/start/bspstart.c
@@ -95,7 +95,7 @@ void bsp_start( void )
   get_ppc_cpu_revision();
 
   ppc_exc_initialize_with_vector_base(
-    (uintptr_t) _Configuration_Interrupt_stack_area_begin,
+    (uintptr_t) _ISR_Stack_area_begin,
     virtex_exc_vector_base
   );
   __asm__ volatile ("mtevpr %0" : : "r" (virtex_exc_vector_base));
diff --git a/bsps/riscv/riscv/start/start.S b/bsps/riscv/riscv/start/start.S
index feb07feedf..8b2575e87b 100644
--- a/bsps/riscv/riscv/start/start.S
+++ b/bsps/riscv/riscv/start/start.S
@@ -61,8 +61,8 @@ SYM(_start):
 
        /* Load stack pointer and branch to secondary processor start if 
necessary */
 #ifdef RTEMS_SMP
-       LADDR   sp, _Configuration_Interrupt_stack_area_begin
-       LADDR   t2, _Configuration_Interrupt_stack_size
+       LADDR   sp, _ISR_Stack_area_begin
+       LADDR   t2, _ISR_Stack_size
        csrr    s0, mhartid
        LADDR   t0, _Per_CPU_Information
        slli    t1, s0, PER_CPU_CONTROL_SIZE_LOG2
@@ -71,7 +71,7 @@ SYM(_start):
        bnez    s0, .Lstart_on_secondary_processor
        add     sp, sp, t2
 #else
-       LADDR   sp, _Configuration_Interrupt_stack_area_end
+       LADDR   sp, _ISR_Stack_area_end
 #endif
 
 #ifdef BSP_START_COPY_FDT_FROM_U_BOOT
diff --git a/bsps/sh/gensh1/start/start.S b/bsps/sh/gensh1/start/start.S
index 6a2941c7e2..88b2512a6e 100644
--- a/bsps/sh/gensh1/start/start.S
+++ b/bsps/sh/gensh1/start/start.S
@@ -66,7 +66,7 @@ SYM (start):
 
        .align 2
 stack_k:
-       .long   SYM(_Configuration_Interrupt_stack_area_end)
+       .long   SYM(_ISR_Stack_area_end)
 edata_k:
        .long   SYM(edata)
 end_k:
diff --git a/bsps/sh/gensh2/start/start.S b/bsps/sh/gensh2/start/start.S
index b8b3f50156..47c725f206 100644
--- a/bsps/sh/gensh2/start/start.S
+++ b/bsps/sh/gensh2/start/start.S
@@ -155,7 +155,7 @@ SYM (start):
 
        .align 2
 stack_k:
-       .long   SYM(_Configuration_Interrupt_stack_area_end)
+       .long   SYM(_ISR_Stack_area_end)
 edata_k:
        .long   SYM(edata)
 end_k:
diff --git a/bsps/sh/gensh2/start/start.ram b/bsps/sh/gensh2/start/start.ram
index 7f6b5faf65..f6bd16e4b2 100644
--- a/bsps/sh/gensh2/start/start.ram
+++ b/bsps/sh/gensh2/start/start.ram
@@ -158,7 +158,7 @@ SYM (start):
 
        .align 2
 stack_k:
-       .long   SYM(_Configuration_Interrupt_stack_area_end)
+       .long   SYM(_ISR_Stack_area_end)
 edata_k:
        .long   SYM(edata)
 end_k:
diff --git a/bsps/sh/gensh2/start/start.rom b/bsps/sh/gensh2/start/start.rom
index 79068daa82..533cf5ee66 100644
--- a/bsps/sh/gensh2/start/start.rom
+++ b/bsps/sh/gensh2/start/start.rom
@@ -67,7 +67,7 @@ SYM (start):
 
        .align 2
 stack_k:
-       .long   SYM(_Configuration_Interrupt_stack_area_end)
+       .long   SYM(_ISR_Stack_area_end)
 edata_k:
        .long   SYM(edata)
 end_k:
diff --git a/bsps/sh/gensh4/start/start.S b/bsps/sh/gensh4/start/start.S
index 711583ed6d..57b23b6845 100644
--- a/bsps/sh/gensh4/start/start.S
+++ b/bsps/sh/gensh4/start/start.S
@@ -215,7 +215,7 @@ _vbr_base_k:
 __VBR_Saved_k:
         .long   SYM(_VBR_Saved)
 stack_k:
-        .long  SYM(_Configuration_Interrupt_stack_area_end)
+        .long  SYM(_ISR_Stack_area_end)
 __bss_start_k:
         .long   __bss_start
 __bss_end_k:
diff --git a/bsps/sh/shsim/start/start.S b/bsps/sh/shsim/start/start.S
index e116704370..b5294e3861 100644
--- a/bsps/sh/shsim/start/start.S
+++ b/bsps/sh/shsim/start/start.S
@@ -68,7 +68,7 @@ SYM (start):
 
        .align 2
 stack_k:
-       .long   SYM(_Configuration_Interrupt_stack_area_end)
+       .long   SYM(_ISR_Stack_area_end)
 edata_k:
        .long   SYM(edata)
 end_k:
diff --git a/bsps/sparc/shared/start/start.S b/bsps/sparc/shared/start/start.S
index 0be93ed015..5fc1248a24 100644
--- a/bsps/sparc/shared/start/start.S
+++ b/bsps/sparc/shared/start/start.S
@@ -319,12 +319,12 @@ SYM(hard_reset):
 
        set     SYM(rdb_start), %g5     ! End of RAM
        st      %sp, [%g5]
-       set     SYM(_Configuration_Interrupt_stack_size), %g5
+       set     SYM(_ISR_Stack_size), %g5
 #if defined(START_LEON3_ENABLE_SMP)
        add     %o0, 1, %o0
        smul    %o0, %g5, %g5
 #endif
-       set     SYM(_Configuration_Interrupt_stack_area_begin), %sp
+       set     SYM(_ISR_Stack_area_begin), %sp
        add     %sp, %g5, %sp
        sub     %sp, 4, %sp             ! stack starts at end of area - 4
        andn    %sp, 0x0f, %sp          ! align stack on 16-byte boundary
diff --git a/bsps/v850/gdbv850sim/start/start.S 
b/bsps/v850/gdbv850sim/start/start.S
index 82ae4ebcb7..5f203d798f 100644
--- a/bsps/v850/gdbv850sim/start/start.S
+++ b/bsps/v850/gdbv850sim/start/start.S
@@ -9,7 +9,7 @@ _start:
 
        movea   255,            r0,     r20
        mov     65535,          r21
-       mov     hilo(__Configuration_Interrupt_stack_area_end), sp
+       mov     hilo(__ISR_Stack_area_end),     sp
        mov     hilo(__ep),     ep
        mov     hilo(__gp),     gp
        mov     hilo(__ctbp),   r6
@@ -36,8 +36,8 @@ _start:
        movea   255,            r0,     r20
        mov     r0,             r21
        ori     65535,          r0,     r21
-       movhi   hi(__Configuration_Interrupt_stack_area_end),   r0,     sp
-       movea   lo(__Configuration_Interrupt_stack_area_end),   sp,     sp
+       movhi   hi(__ISR_Stack_area_end),       r0,     sp
+       movea   lo(__ISR_Stack_area_end),       sp,     sp
        movhi   hi(__ep),       r0,     ep
        movea   lo(__ep),       ep,     ep
        movhi   hi(__gp),       r0,     gp
diff --git a/cpukit/include/rtems/confdefs.h b/cpukit/include/rtems/confdefs.h
index 64577b92d7..a52d53061a 100644
--- a/cpukit/include/rtems/confdefs.h
+++ b/cpukit/include/rtems/confdefs.h
@@ -1176,16 +1176,16 @@ extern rtems_initialization_tasks_table 
Initialization_tasks[];
 
 #ifdef CONFIGURE_INIT
   RTEMS_DEFINE_GLOBAL_SYMBOL(
-    _Configuration_Interrupt_stack_size,
+    _ISR_Stack_size,
     CONFIGURE_INTERRUPT_STACK_SIZE
   );
 
-  char _Configuration_Interrupt_stack_area_begin[
+  char _ISR_Stack_area_begin[
     _CONFIGURE_MAXIMUM_PROCESSORS * CONFIGURE_INTERRUPT_STACK_SIZE
   ] RTEMS_ALIGNED( CPU_INTERRUPT_STACK_ALIGNMENT )
   RTEMS_SECTION( ".rtemsstack.interrupt.begin" );
 
-  const char _Configuration_Interrupt_stack_area_end[ 0 ]
+  const char _ISR_Stack_area_end[ 0 ]
     RTEMS_SECTION( ".rtemsstack.interrupt.end" ) = { };
 #endif
 
diff --git a/cpukit/include/rtems/config.h b/cpukit/include/rtems/config.h
index c910aa07bb..23b6132c38 100644
--- a/cpukit/include/rtems/config.h
+++ b/cpukit/include/rtems/config.h
@@ -32,6 +32,7 @@ extern "C" {
  */
 
 #include <rtems/score/object.h>
+#include <rtems/score/isr.h>
 #include <rtems/score/watchdog.h>
 #include <rtems/rtems/config.h>
 #include <rtems/posix/config.h>
@@ -294,34 +295,8 @@ extern const rtems_configuration_table Configuration;
 #define rtems_configuration_get_idle_task_stack_size() \
         (Configuration.idle_task_stack_size)
 
-/**
- * @brief Global symbol with a value equal to the configure interrupt stack 
size.
- *
- * This global symbol is defined by the application configuration option
- * CONFIGURE_INIT_TASK_STACK_SIZE via <rtems/confdefs.h>.
- */
-RTEMS_DECLARE_GLOBAL_SYMBOL( _Configuration_Interrupt_stack_size );
-
-/**
- * @brief The interrupt stack area begin.
- *
- * The interrupt stack area is defined by the application configuration via
- * <rtems/confdefs.h>.  The size of the area depends on
- * CONFIGURE_INIT_TASK_STACK_SIZE and CONFIGURE_MAXIMUM_PROCESSORS.
- */
-extern char _Configuration_Interrupt_stack_area_begin[];
-
-/**
- * @brief The interrupt stack area end.
- *
- * The interrupt stack area is defined by the application configuration via
- * <rtems/confdefs.h>.  The size of the area depends on
- * CONFIGURE_INIT_TASK_STACK_SIZE and CONFIGURE_MAXIMUM_PROCESSORS.
- */
-extern const char _Configuration_Interrupt_stack_area_end[];
-
 #define rtems_configuration_get_interrupt_stack_size() \
-        ((size_t) _Configuration_Interrupt_stack_size)
+        ((size_t) _ISR_Stack_size)
 
 #define rtems_configuration_get_stack_allocate_init_hook() \
         (Configuration.stack_allocate_init_hook)
diff --git a/cpukit/include/rtems/score/isr.h b/cpukit/include/rtems/score/isr.h
index d9c03b807f..58dbb843c6 100644
--- a/cpukit/include/rtems/score/isr.h
+++ b/cpukit/include/rtems/score/isr.h
@@ -76,6 +76,32 @@ typedef ISR_Handler ( *ISR_Handler_entry )(
 extern ISR_Handler_entry _ISR_Vector_table[ CPU_INTERRUPT_NUMBER_OF_VECTORS ];
 #endif
 
+/**
+ * @brief Global symbol with a value equal to the configure interrupt stack 
size.
+ *
+ * This global symbol is defined by the application configuration option
+ * CONFIGURE_INIT_TASK_STACK_SIZE via <rtems/confdefs.h>.
+ */
+RTEMS_DECLARE_GLOBAL_SYMBOL( _ISR_Stack_size );
+
+/**
+ * @brief The interrupt stack area begin.
+ *
+ * The interrupt stack area is defined by the application configuration via
+ * <rtems/confdefs.h>.  The size of the area depends on
+ * CONFIGURE_INIT_TASK_STACK_SIZE and CONFIGURE_MAXIMUM_PROCESSORS.
+ */
+extern char _ISR_Stack_area_begin[];
+
+/**
+ * @brief The interrupt stack area end.
+ *
+ * The interrupt stack area is defined by the application configuration via
+ * <rtems/confdefs.h>.  The size of the area depends on
+ * CONFIGURE_INIT_TASK_STACK_SIZE and CONFIGURE_MAXIMUM_PROCESSORS.
+ */
+extern const char _ISR_Stack_area_end[];
+
 /**
  *  @brief Initialize the ISR handler.
  *
diff --git a/cpukit/libmisc/stackchk/check.c b/cpukit/libmisc/stackchk/check.c
index 3670210f5b..ce7d1a08cb 100644
--- a/cpukit/libmisc/stackchk/check.c
+++ b/cpukit/libmisc/stackchk/check.c
@@ -502,7 +502,7 @@ static void Stack_check_Prepare_interrupt_stacks( void )
   uint32_t      cpu_max;
 
   stack.size = rtems_configuration_get_interrupt_stack_size();
-  stack.area = _Configuration_Interrupt_stack_area_begin;
+  stack.area = _ISR_Stack_area_begin;
   cpu_max = rtems_configuration_get_maximum_processors();
 
   for ( cpu_index = 0; cpu_index < cpu_max; ++cpu_index ) {
diff --git a/cpukit/score/cpu/m68k/cpu.c b/cpukit/score/cpu/m68k/cpu.c
index 77a91535c3..87e0fe384d 100644
--- a/cpukit/score/cpu/m68k/cpu.c
+++ b/cpukit/score/cpu/m68k/cpu.c
@@ -62,7 +62,7 @@ int (*_FPSP_install_raw_handler)(
 static void m68k_install_interrupt_stack( void )
 {
 #if ( M68K_HAS_SEPARATE_STACKS == 1 )
-  uintptr_t isp = (uintptr_t) _Configuration_Interrupt_stack_area_end;
+  uintptr_t isp = (uintptr_t) _ISR_Stack_area_end;
 
   __asm__ volatile ( "movec %0,%%isp" : "=r" (isp) : "0" (isp) );
 #endif
diff --git a/cpukit/score/src/isr.c b/cpukit/score/src/isr.c
index 6a1b307f42..4a7bc5fcce 100644
--- a/cpukit/score/src/isr.c
+++ b/cpukit/score/src/isr.c
@@ -48,7 +48,7 @@ void _ISR_Handler_initialization( void )
 
   stack_size = rtems_configuration_get_interrupt_stack_size();
   cpu_max = rtems_configuration_get_maximum_processors();
-  stack_low = _Configuration_Interrupt_stack_area_begin;
+  stack_low = _ISR_Stack_area_begin;
 
   for ( cpu_index = 0 ; cpu_index < cpu_max; ++cpu_index ) {
     Per_CPU_Control *cpu;
diff --git a/bsps/powerpc/haleakala/start/dlentry.S 
b/bsps/powerpc/haleakala/start/dlentry.S
index 54fbb7668b..43dde91255 100644
--- a/bsps/powerpc/haleakala/start/dlentry.S
+++ b/bsps/powerpc/haleakala/start/dlentry.S
@@ -54,7 +54,7 @@
  *    .bss
  * see linker command file for section placement
  *
  *  The initial stack is set to _Configuration_Interrupt_stack_area_end.
  *
  *  All the entry veneer has to do is to clear the BSS.
  */
@@ -98,7 +98,7 @@ sbss_length:
 sbss_addr:
                .long   sbss.start
 stack_top:
-               .long   _Configuration_Interrupt_stack_area_end
+               .long   _ISR_Stack_area_end
 PUBLIC_VAR (text_addr)
 text_addr:
         .long   text.start
@@ -54,7 +54,7 @@
  * see linker command file for section placement
  *
- *  The initial stack is set to _Configuration_Interrupt_stack_area_end.
+ *  The initial stack is set to _ISR_Stack_area_end.
  *
  *  All the entry veneer has to do is to clear the BSS.
diff --git a/bsps/powerpc/virtex4/start/start.S 
b/bsps/powerpc/virtex4/start/start.S
index d4b8419551..5189ec5af6 100644
--- a/bsps/powerpc/virtex4/start/start.S
+++ b/bsps/powerpc/virtex4/start/start.S
@@ -82,7 +82,7 @@
  *    .bss
  *  see linker command file for section placement
  *
  *  The initial stack is set to _Configuration_Interrupt_stack_area_end.
  *
  */
 
@@ -109,7 +109,7 @@ bss_length:
 bss_addr:
         .long   __bss_start
 stack_top:
-        .long   _Configuration_Interrupt_stack_area_end
+        .long   _ISR_Stack_area_end
 dccr_contents:
         .long   __dccr
 iccr_contents:
@@ -82,7 +82,7 @@
  *  see linker command file for section placement
  *
- *  The initial stack is set to _Configuration_Interrupt_stack_area_end.
+ *  The initial stack is set to _ISR_Stack_area_end.
  *
  */
diff --git a/bsps/powerpc/virtex5/start/start.S 
b/bsps/powerpc/virtex5/start/start.S
index b63c103b14..c17587fbce 100644
--- a/bsps/powerpc/virtex5/start/start.S
+++ b/bsps/powerpc/virtex5/start/start.S
@@ -86,7 +86,7 @@
  *    .bss
  *  see linker command file for section placement
  *
  *  The initial stack is set to _Configuration_Interrupt_stack_area_end.
  *
  *  All the entry veneer has to do is to clear the BSS.
  */
@@ -114,7 +114,7 @@ bss_length:
 bss_addr:
         .long   __bss_start
 stack_top:
-        .long   _Configuration_Interrupt_stack_area_end
+        .long   _ISR_Stack_area_end
 
 
         .eject
@@ -86,7 +86,7 @@
  *  see linker command file for section placement
  *
- *  The initial stack is set to _Configuration_Interrupt_stack_area_end.
+ *  The initial stack is set to _ISR_Stack_area_end.
  *
  *  All the entry veneer has to do is to clear the BSS.
-- 
2.16.4

_______________________________________________
devel mailing list
devel@rtems.org
http://lists.rtems.org/mailman/listinfo/devel

Reply via email to